@@ -67,7 +67,7 @@ switch( $_GET['action'] ) {
 			$_POST[ 'dashboard_blog' ] = $current_site->blog_id;
 			$dashboard_blog_id = $current_site->blog_id;
 		} else {
-			$dashboard_blog = sanitize_user( str_replace( '.', '', str_replace( $current_site->domain . $current_site->path, '', $_POST[ 'dashboard_blog' ] ) ) );
+			$dashboard_blog = untrailingslashit( sanitize_user( str_replace( '.', '', str_replace( $current_site->domain . $current_site->path, '', $_POST[ 'dashboard_blog' ] ) ) ) );
 			$blog_details = get_blog_details( $dashboard_blog );
 			if ( false === $blog_details ) {
 				if ( is_numeric( $dashboard_blog ) )
@@ -86,6 +86,9 @@ switch( $_GET['action'] ) {
 				$dashboard_blog_id = $blog_details->blog_id;
 			}
 		}
+		if ( is_wp_error( $dashboard_blog_id ) ) {
+			wp_die( __( 'Problem creating dashboard blog: ' ) . $dashboard_blog_id->get_error_message() );
+		}
 		if( $_POST[ 'dashboard_blog_orig' ] != $_POST[ 'dashboard_blog' ] ) {
 			$users = get_users_of_blog( get_site_option( 'dashboard_blog' ) );
 			$move_users = array();
@@ -102,7 +105,7 @@ switch( $_GET['action'] ) {
 			}
 		}
 		update_site_option( "dashboard_blog", $dashboard_blog_id );
-		$options = array( 'menu_items', 'mu_media_buttons', 'blog_upload_space', 'upload_filetypes', 'site_name', 'first_post', 'welcome_email', 'fileupload_maxk', 'admin_notice_feed' );
+		$options = array( 'menu_items', 'mu_media_buttons', 'blog_upload_space', 'upload_filetypes', 'site_name', 'first_post', 'first_page', 'first_comment', 'first_comment_url', 'first_comment_author', 'welcome_email', 'welcome_user_email', 'fileupload_maxk', 'admin_notice_feed' );
 		foreach( $options as $option_name ) {
 			$value = stripslashes_deep( $_POST[ $option_name ] );
 			update_site_option( $option_name, $value );
@@ -125,7 +128,7 @@ switch( $_GET['action'] ) {
 		// Update more options here
 		do_action( 'update_wpmu_options' );
 
-		wp_redirect( add_query_arg( "updated", "true", $_SERVER['HTTP_REFERER'] ) );
+		wp_redirect( add_query_arg( "updated", "true", 'wpmu-options.php' ) );
 		exit();
 	break;
 
@@ -197,6 +200,9 @@ switch( $_GET['action'] ) {
 			$c = 1;
 			$count = count( $_POST['option'] );
 			foreach ( (array) $_POST['option'] as $key => $val ) {
+				if ( $key == 0 )
+					continue;
+				$val = stripslashes_deep( $val );
 				if( $c == $count ) {
 					update_option( $key, $val );
 				} else {
